.. user-manual:

******************
Cysgp4 user manual
******************

.. currentmodule:: cysgp4



Introduction
============

TODO

Using cysgp4
============

TODO


Benchmarks
==========

TODO

See Also
========

- `C++ SGP4 Satellite Library <https://www.danrw.com/sgp4/>`_ by Daniel Warner
- `sgp4 Python package <https://pypi.org/project/sgp4/>`_ by Brandon Rhodes
- `Two-line element strings (TLE)
  <https://en.wikipedia.org/wiki/Two-line_element_set>`_


Reference/API
=============

.. automodapi:: cysgp4
    :inherited-members:
    :no-inheritance-diagram:
    :no-main-docstr:
..    :no-heading:

